@@ -557,7 +557,16 @@ class NumerousClient:
                     current_row[d.tag] += list(d.values)
 
             if b.row_complete:
-                for i in range(len(current_row['_index'])):
+                len_index = len(current_row['_index'])
+
+                wrong_len_tags = []
+                for k in list(current_row.keys()):
+                    if (len_cr:=len(current_row[k])) != len_index:
+                        wrong_len_tags.append((k, len_cr))
+                if len(wrong_len_tags)>0:
+                    raise ValueError(f'The following tags have a wrong number of data points returned (_index has {len_index}: '+"\n".join([tag[0] +': '+str(tag[1]) for tag in wrong_len_tags]))
+
+                for i in range(len_index):
                     current_ix = current_row['_index'][i] if time_range else i
 
                     if current_ix >= start and current_ix < end:
@@ -734,7 +743,7 @@ class NumerousClient:
                                                                  'offset': iv['offset']}
                         input_source_types[iv['dataSourceID']]='scenario'
 
-                    elif iv['dataSourceType'] == 'csv':
+                    elif iv['dataSourceType'] in ['dataset','csv']:
 
                         only_static = False
 
@@ -832,6 +841,8 @@ class DynamicSource:
             continuous = True
             subscribe = False
             log.debug('Continous mode set on input source')
+        else:
+            continuous = False
 
         self.generator = client.read_data_as_row(tags=[s['tag'] for s in spec.values()], scenario=scenario, start=t0, subscribe=subscribe)
         self.spec = spec
